given and old and new dataset, will calculate the impact data releases and revisions have on the estimate of a target variable.
gen_news(old_y, new_y, output_dfm, target_variable, target_period)dataframe of variables, size (n_obs, n_variables). Must include in 1st column a series of type date, called "date", all data already stationary.
dataframe of variables, size (n_obs, n_variables). Must include in 1st column a series of type date, called "date", all data already stationary. Must contain same columns as old_y.
list, the output of the dfm() function.
name of the target column.
date of forecast to view impacts on.
A list containing the following elements:
same as input.
same as input.
forecast for target variable with old data.
forecast for target variable with new data.
forecast of variables for target period. Only shows for variables that were newly published between old and new dataset.
actual published value of variables for target period. Only shows for variables that were newly published between old and new dataset.
weight of each data release
table summarising forecast, actual, weight and impact of data releases
impact of data revisions on nowcast.
impact of data releases on nowcast.
total impact (from data revision and data releases).